@@ -40,7 +40,7 @@ _S(CAP_SYS_MODULE,		"sys_module"		)
 _S(CAP_SYS_RAWIO,		"sys_rawio"		)
 _S(CAP_SYS_CHROOT,		"sys_chroot"		)
 _S(CAP_SYS_PTRACE,		"sys_ptrace"		)
-_S(CAP_SYS_PACCT,		"sys_psacct"		)
+_S(CAP_SYS_PACCT,		"sys_pacct"		)
 _S(CAP_SYS_ADMIN,		"sys_admin"		)
 _S(CAP_SYS_BOOT,		"sys_boot"		)
 _S(CAP_SYS_NICE,		"sys_nice"		)
